@@ -1,7 +1,7 @@
 import os
 from pprint import pprint
 from pygqlc import GraphQLClient
-from .worker import ValiotWorker, QueueType, PollingMode, JobConfigMode
+from .worker import ValiotWorker, QueueType, PollingMode, JobConfigMode, LogLevel
 # ! Create main helpers:
 gql = GraphQLClient()
 vw = ValiotWorker()
@@ -26,16 +26,22 @@ vw.setJobConfigMode(JobConfigMode.SYNC)
     enabled=True,
     queueType=QueueType.FREQUENCY,
 )
-def test_job(job_id, update_job, **_):
+def test_job(**_):
     print("Hi, I'm test job #1")
-    update_job({
-        'id': job_id,
-        'status': 'FINISHED',
-        'output': '{}',
-        'progress': 100
-    })
+    return {'result': 'ok 1'}
 
 
+@vw.job(
+    name='TEST_JOB_SIMPLE_OUTPUT',
+    alias='test job simple output',
+    description='',
+    enabled=True,
+    queueType=QueueType.ON_DEMAND,
+)
+def test_job(**_):
+    print("Hi, I'm test job simple output")
+    return 'ok simple output'
+
 @vw.job(
     name='TEST_JOB_2',
     alias='test job 2',
@@ -44,15 +50,20 @@ def test_job(job_id, update_job, **_):
     enabled=True,
     queueType=QueueType.FREQUENCY,
 )
-def test_job_2(job_id, update_job, **_):
-    print("Hi, I'm test job #2")
-    update_job({
-        'id': job_id,
-        'status': 'FINISHED',
-        'output': '{}',
-        'progress': 100
-    })
+def test_job_2(log, **_):
+    log(LogLevel.INFO, "Hi, I'm test job #2")
+    return {'result': 'ok 2'}
 
+@vw.job(
+    name='TEST_JOB_THAT_FAILS',
+    alias='test job that fails',
+    description='',
+    enabled=True,
+    queueType=QueueType.ON_DEMAND,
+)
+def test_job_that_fails(log, **_):
+    log(LogLevel.INFO, "Hi, I'm test job #3")
+    raise Exception('This job fails')
 
 def main():
     print('main for valiot worker')
