@@ -5,7 +5,5 @@ from tzlocal import get_localzone
 
 def getUtcDate(date: datetime) -> datetime:
     utc = timezone('UTC')
-    tz = get_localzone()  # local timezone
-    local_date = date.replace(tzinfo=tz)
-    utc_date = local_date.astimezone(utc)
+    utc_date = date.astimezone(utc)
     return utc_date
