@@ -56,3 +56,28 @@ subscription {
   }
 }
 '''
+
+LOCKS_UPDATED = '''
+subscription locksUpdated {
+  queueLocks {
+    successful
+    action
+    messages {
+      field
+      message
+    }
+    result {
+      id
+      insertedAt
+      updatedAt
+      active
+      startAt
+      endAt
+      queue {
+        id
+        name
+      }
+    }
+  }
+}
+'''
\ No newline at end of file
