@@ -718,25 +718,24 @@ class ValiotWorker():
         current_queue = __.get(self.currentQueues, queue_index)
         if queue_index == -1:
             return # no op, queue not found
-        match action:
-            case 'created':
-                self.log(LogLevel.INFO, f'Queue {queue["name"]} locked')
-                self.currentQueues[queue_index]['locks'] = [lock]
-            case 'updated':
-                self.log(LogLevel.INFO, f'Queue {queue["name"]} lock updated')
-                lock_index = __.find_index(current_queue['locks'], lambda l: l['id'] == lock['id'])
-                if lock_index == -1:
-                    self.currentQueues[queue_index]['locks'].append(lock)
-                    self.currentQueues[queue_index]['locks'] = __.sort_by(self.currentQueues[queue_index]['locks'], 'updatedAt', reverse=True)
-                else:
-                    self.currentQueues[queue_index]['locks'][lock_index] = lock
-            case 'deleted':
-                self.log(LogLevel.INFO, f'Queue {queue["name"]} lock released')
-                lock_index = __.find_index(current_queue['locks'], lambda l: l['id'] == lock['id'])
-                if lock_index != -1:
-                    self.currentQueues[queue_index]['locks'].pop(lock_index)
-            case _:
-                self.log(LogLevel.INFO, f'Queue {queue["name"]} unknown lock action: {action}')
+        if action == 'created':
+            self.log(LogLevel.INFO, f'Queue {queue["name"]} locked')
+            self.currentQueues[queue_index]['locks'] = [lock]
+        elif action == 'updated':
+            self.log(LogLevel.INFO, f'Queue {queue["name"]} lock updated')
+            lock_index = __.find_index(current_queue['locks'], lambda l: l['id'] == lock['id'])
+            if lock_index == -1:
+                self.currentQueues[queue_index]['locks'].append(lock)
+                self.currentQueues[queue_index]['locks'] = __.sort_by(self.currentQueues[queue_index]['locks'], 'updatedAt', reverse=True)
+            else:
+                self.currentQueues[queue_index]['locks'][lock_index] = lock
+        elif action == 'deleted':
+            self.log(LogLevel.INFO, f'Queue {queue["name"]} lock released')
+            lock_index = __.find_index(current_queue['locks'], lambda l: l['id'] == lock['id'])
+            if lock_index != -1:
+                self.currentQueues[queue_index]['locks'].pop(lock_index)
+        else:
+            self.log(LogLevel.INFO, f'Queue {queue["name"]} unknown lock action: {action}')
 
     def workerQueueEnabled(self, queue):
         """This function checks if the queue is enable.
